MerchantAccountInformation class

Constructors

MerchantAccountInformation({required int id, String? globalUniqueId, String? pan, String? merchantId, String? criteria})
MerchantAccountInformation.parse(int id, String data)
factory

Properties

criteria → String?
final
globalUniqueId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
merchantId → String?
final
pan → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited