Qris class

Represents a parsed QRIS code.

Constructors

Qris({required String rawData, required String payloadFormatIndicator, required String pointOfInitiationMethod, required Map<int, MerchantAccountInformation> merchantAccountInformation, String? merchantCategoryCode, String? transactionCurrency, String? transactionAmount, String? tipOrConvenienceIndicator, String? valueOfConvenienceFeeFixed, String? valueOfConvenienceFeePercentage, String? countryCode, String? merchantName, String? merchantCity, String? postalCode, AdditionalDataField? additionalDataField, required String crc})
Qris.parse(String rawData)
Parses a QRIS string into a Qris object.
factory

Properties

additionalDataField → AdditionalDataField?
final
countryCode → String?
final
crc → String
final
hashCode → int
The hash code for this object.
no setterinherited
merchantAccountInformation → Map<int, MerchantAccountInformation>
final
merchantCategoryCode → String?
final
merchantCity → String?
final
merchantName → String?
final
payloadFormatIndicator → String
final
pointOfInitiationMethod → String
final
postalCode → String?
final
rawData → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tipOrConvenienceIndicator → String?
final
transactionAmount → String?
final
transactionCurrency → String?
final
valueOfConvenienceFeeFixed → String?
final
valueOfConvenienceFeePercentage → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited